@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE libraries
-   Copyright (c) 2007 Thiago Macieira <thiago@kde.org>
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <kconfiggroup.h>
@@ -166,10 +153,24 @@ static bool writeEntryGui(KConfigGroup *cg, const char *key, const QVariant &pro
         cg->writeEntry(key, list, pFlags);
         return true;
     }
-    case QMetaType::QFont:
-        cg->writeEntry(key, prop.toString().toUtf8(), pFlags);
+    case QMetaType::QFont: {
+        QFont f = prop.value<QFont>();
+        // If the styleName property is set for a QFont, using setBold(true) would
+        // lead to Qt using an "emboldended"/synthetic font style instead of using
+        // the bold style provided by the font itself; the latter looks much better
+        // than the former. For more details see:
+        // https://bugreports.qt.io/browse/QTBUG-63792
+        // https://bugs.kde.org/show_bug.cgi?id=378523
+        if (f.weight() == QFont::Normal
+            && (f.styleName() == QLatin1String("Regular")
+            || f.styleName() == QLatin1String("Normal")
+            || f.styleName() == QLatin1String("Book")
+            || f.styleName() == QLatin1String("Roman"))) {
+            f.setStyleName(QString());
+        }
+        cg->writeEntry(key, f.toString().toUtf8(), pFlags);
         return true;
-
+    }
     case QMetaType::QPixmap:
     case QMetaType::QImage:
     case QMetaType::QBrush:
